@@ -38,9 +38,9 @@ Here is an example of constructing a simple feature file using fontFeatures::
 
 from collections import OrderedDict, namedtuple
 from fontTools.feaLib.ast import ValueRecord as feaLibValueRecord
+from fontTools.feaLib.variableScalar import VariableScalar
 from itertools import chain
 from copy import copy
-from .variableScalar import VariableScalar
 
 
 class FontFeatures:
@@ -321,6 +321,8 @@ class FontFeatures:
         self.routines[index : index + 1] = allroutines
         for user in usedin:
             for lookuplist in user.lookups:
+                if lookuplist is None:
+                    continue
                 i = 0
                 while i < len(lookuplist):
                     lookup = lookuplist[i]
@@ -334,6 +336,8 @@ class FontFeatures:
                     i = i + 1
         # Same trick for features
         for lookuplist in self.features.values():
+            if lookuplist is None:
+                continue
             i = 0
             while i < len(lookuplist):
                 lookup = lookuplist[i]
@@ -737,7 +741,7 @@ class ValueRecord(feaLibValueRecord):
     @property
     def is_variable(self):
         """Returns true if any of the elements of the value record are a
-        :py:class:`fontFeatures.variableScalar.VariableScalar`."""
+        :py:class:`fontTools.feaLib.VariableScalar`."""
         return any(
             isinstance(x, VariableScalar)
             for x in [
