@@ -2,9 +2,19 @@
 import fontTools.feaLib.ast as feaast
 from glyphtools import categorize_glyph
 import warnings
-from fontFeatures.variableScalar import VariableScalar
+from fontTools.feaLib.variableScalar import VariableScalar
 
 
+def fix_scalar(scalar):
+    if isinstance(scalar, int):
+        return scalar
+    if isinstance(scalar, float):
+        return int(scalar)
+    if hasattr(scalar, "model"):
+        # assume it's a variable scalar of some kind
+        return scalar
+    raise ValueError("Illegal anchor position %s" % scalar)
+
 def _glyphref(g):
     if len(g) == 1:
         return feaast.GlyphName(g[0])
@@ -35,33 +45,28 @@ def feaPreamble(self, ff):
         ff.scratch["mark_classes_done"] = {}
     b = feaast.Block()
     for mark in self.markslist:
-        if not (self.base_name, tuple(mark[0])) in ff.scratch["mark_classes_done"]:
+        if not (self.mark_name, tuple(mark[0])) in ff.scratch["mark_classes_done"]:
             b.statements.append(
                 feaast.MarkClassDefinition(
-                    feaast.MarkClass(self.base_name),
-                    feaast.Anchor(*mark[1]),
+                    feaast.MarkClass(self.mark_name),
+                    feaast.Anchor(fix_scalar(mark[1][0]), fix_scalar(mark[1][1])),
                     _glyphref(mark[0]),
                 )
             )
-            ff.scratch["mark_classes_done"][(self.base_name, tuple(mark[0]))] = True
+            ff.scratch["mark_classes_done"][(self.mark_name, tuple(mark[0]))] = True
     return [b]
 
 
 def asFeaAST(self):
     b = feaast.Block()
-    # if any(
-    #     isinstance(x[0], VariableScalar) or isinstance(x[1], VariableScalar)
-    #     for x in list(self.bases.values()) + list(self.marks.values())
-    # ):
-    #     raise ValueError("Can't directly express a variable anchor in FEA")
     if self.is_cursive:
         allglyphs = set(self.bases.keys()) | set(self.marks.keys())
         for g in allglyphs:
             b.statements.append(
                 feaast.CursivePosStatement(
                     _glyphref([g]),
-                    g in self.bases and feaast.Anchor(*self.bases[g]),
-                    g in self.marks and feaast.Anchor(*self.marks[g]),
+                    g in self.bases and feaast.Anchor(fix_scalar(self.bases[g][0]),fix_scalar(self.bases[g][1])),
+                    g in self.marks and feaast.Anchor(fix_scalar(self.marks[g][0]),fix_scalar(self.marks[g][1])),
                 )
             )
     else:
@@ -77,7 +82,7 @@ def asFeaAST(self):
             b.statements.append(
                 statementtype(
                     _glyphref(base[0]),
-                    [[feaast.Anchor(*base[1]), feaast.MarkClass(self.base_name)]],
+                    [[feaast.Anchor(fix_scalar(base[1][0]), fix_scalar(base[1][1])), feaast.MarkClass(self.mark_name)]],
                 )
             )
 
